(installation)=
# Installation


The only pre-requisite to install R2X is [Python
3.11](https://www.python.org/downloads/release/python-3110/) or greater.


### Python version support

Python 3.11, 3.12.


## Installation options

The R2X framework is available to install on
[PyPI](https://pypi.org/project/r2x/) and can be installed using any python
package manager of your preference, but we recommend using
[uv](https://docs.astral.sh/uv/getting-started/installation/).


### Using UV

```console
uv tool install r2x
```

### Using pip

```console
python -m pip install r2x
```

## Upgrading options

### Using UV

```console
uv tool upgrade r2x
```

### Using pip
```console
python -m pip install --upgrade r2x
```

## Next steps

See the [getting started](#getting-started) guide or jump straight to the [how-to's](#howtos).
